@@ -507,6 +507,10 @@ ASSIGNMENTS=PHP_VERSION_REQD=55
 PKGNAME=ap22-php55-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PHP_VERSION_REQD=56
+PKGNAME=ap22-php56-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PHP_VERSION_REQD=53
 PKGNAME=ap22-php53-X
 PKGPATH=www/ap-php
@@ -523,6 +527,10 @@ ASSIGNMENTS=PHP_VERSION_REQD=55
 PKGNAME=ap22-php55-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PHP_VERSION_REQD=56
+PKGNAME=ap22-php56-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PHP_VERSION_REQD=53
 PKGNAME=ap22-php53-X
 PKGPATH=www/ap-php
@@ -535,6 +543,10 @@ ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=55
 PKGNAME=ap24-php55-X
 PKGPATH=www/ap-php
 
+ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=56
+PKGNAME=ap24-php56-X
+PKGPATH=www/ap-php
+
 ASSIGNMENTS=PKG_APACHE=apache24,PHP_VERSION_REQD=53
 PKGNAME=ap24-php53-X
 PKGPATH=www/ap-php
